/*
 * User: Tom
 * Date: 5-aug-2004
 * Time: 0:56:34
 */
package com.tombrus.imageConverter.jobs;

import com.tombrus.imageConverter.Job;
import com.tombrus.imageConverter.JobStep;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;

public class ANWBFilter extends JobStep {
    private float   threshold;
    private boolean debug;

    public int initFrom(Job job,String[] args,int i) {
        i = super.initFrom(job,args,i);
        i++;
        if (args.length <=i) {
            throw new Error("usage: -ANWBFilter [DB,]threshold");
        }
        String arg = args[i];
        debug = arg.startsWith("DB,");
        if (debug) {
            arg = arg.substring(3,arg.length());
        }
        threshold = Float.parseFloat(arg);
        return i;
    }

    public void run() {
        BufferedImage image = getJob().getImage();
        if (image!=null && getTraficLevel(image)<threshold && !debug) {
            final Graphics2D g = image.createGraphics();
            g.setBackground(new Color(0,0,0,0));
            g.clearRect(0,0,image.getWidth(),image.getHeight());
            g.dispose();
        }
    }

    private long getTraficLevel(BufferedImage image) {
        long trafficLevel = 0;
        if (image !=null) {
            int   w         = image.getWidth();
            int   h         = image.getHeight();
            int[] newPixels = image.getRGB(0,0,w,h,null,0,w);
            for (int i = 0; i<newPixels.length; i++) {
                Color   newC  = new Color(newPixels[i]);
                int     r      =   newC.getRed();
                int     g      =   newC.getGreen();
                int     b      =   newC.getBlue();
                boolean isJam  =   r >0xf0 && Math.abs(g-b) <=1 && g <200;
                if (isJam) {
                    trafficLevel += g;
                }
                if (debug) {
                    boolean isRoad = (r==0xfe && g==0xfe && b==0xfe) || (r==0xaf && g==0xb6 && b==0xdb);
                    if (!(isJam || isRoad)) {
                        image.setRGB(i %w,i /w,0);
                    }
                }
            }
            trafficLevel /= 1000;
        }
        verbose("Traffic level is "+trafficLevel+": " +(threshold<=trafficLevel?"ABOVE":"BELOW") +" threshold=" +threshold);
        return trafficLevel;
    }
}